@@ -135,7 +135,7 @@ fn identify_chars(input: &str) -> Result<String, String> {
 
 #[test]
 fn tests() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
 
     let input = include_str!("day10_input.txt");
     test_part_one!(input => "10888".to_string());
