@@ -143,7 +143,7 @@ pub fn solve(input: &mut Input) -> Result<usize, String> {
 
 #[test]
 fn tests() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
 
     test_part_one!(
             ".#.#...|#.
